clear();
close(winsid()); // Close all opened figures

dx = (0:0.1:1.2)';  // increment in element spacing

for i = 1:length(dx)
    // Read the AN-SOF output file for each element spacing
    filename = 'C:/AN-SOF/2elementquad' + string(i) + '_PowerBudget.csv';
    [M, c] = csvRead(filename, ';', [], [], [], [], [], 3);
    G(i) = M(1,10);  // Gain in dBi is in 10th column
    
    filename = 'C:/AN-SOF/2elementquad' + string(i) + '_FarField27500000.csv';
    [E, c] = csvRead(filename, ';', [], [], [], [], [], 3);
    Ef(i) = E(19,4); // E-field at front is in 19th row, 4th column
    Eb(i) = E(1351,4); // E-field at back is in 1351st row, 4th column
end

// Export Gain vs. Incremental Spacing
csvWrite([dx G], 'C:/AN-SOF/2elementquad_gain.csv');

// Plot Gain vs. Incremental Spacing
figure(1);
clf(1);
title('Gain of 2 Element Quad Antenna', 'fontsize', 3);
xlabel('Incremental element spacing [m]', 'fontsize', 2);
ylabel('Gain [dBi]', 'fontsize', 2);
plot(dx, G, 'b-o');
p = get("hdl");
p.children.thickness = 2;
set(gca(),"grid",[1 1]);

// Plot F/B vs. Incremental Spacing
figure(2);
clf(2);
title('F/B of 2 Element Quad Antenna', 'fontsize', 3);
xlabel('Incremental element spacing [m]', 'fontsize', 2);
ylabel('F/B [dB]', 'fontsize', 2);
plot(dx, 20.*log10(Ef./Eb), 'b-o');
p = get("hdl");
p.children.thickness = 2;
set(gca(),"grid",[1 1]);
